# Single bid received (R018)

Only one tenderer submitted a bid.

## Methodology

A contracting process is flagged if the number of tenderers is 1 and the procurement method is **competitive** (`/tender/procurementMethod` is 'open' or 'selective').

:::{admonition} Example
:class: seealso

The Ministry of Education publishes an open opportunity and receives a single bid.
:::

:::{admonition} Why is this a red flag?
:class: hint

In a competitive procedure, a lack of competition might correspond to a *suppression* of competition and can represent the ideal outcome for a corrupt buyer and pre-determined bidder.
:::

<small>Based on "Single bidder" in [*An Objective Corruption Risk Index Using Public Procurement Data*](https://www.researchgate.net/publication/301646354_An_Objective_Corruption_Risk_Index_Using_Public_Procurement_Data).</small>

## Output

The indicator's value is always 1.0.

## Configuration

All configuration is optional.

To override the default **competitive** procurement methods, add to your settings file, as a pipe-separated list, for example:

```ini
[R018]
procurement_methods = open|selective # default
```

## Demonstration

*Input*

:::{literalinclude} ../../../examples/R/018.jsonl
:language: json
:::

*Output*

```console
$ ocdscardinal indicators --settings docs/examples/settings.ini --no-meta docs/examples/R/018.jsonl
{"OCID":{"F":{"R018":1.0}}}

```
